# coding: utf-8
#

__apk_version__ = '1.1.4'
# 1.1.4 add ADB_EDITOR_CODE broadcast support, fix bug （toast捕获导致app闪退)
# 1.1.3 use thread to make watchers.watched faster, try to fix input method type multi
# 1.1.2 fix count error when have child && sync watched, to prevent watchers.remove error
# 1.1.1 support toast capture
# 1.1.0 update uiautomator-v18:2.1.2 -> uiautomator-v18:2.1.3 (This version fixed setWaitIdleTimeout not working bug)
# 1.0.14 catch NullException, add gps mock support
# 1.0.13 whatsinput suppoort, but not very well
# 1.0.12 add toast support
# 1.0.11 add auto install support
# 1.0.10 fix service not started bug
# 1.0.9 fix apk version code and version name
# ERR: 1.0.8 bad version number. show ip on notification
# ERR: 1.0.7 bad version number. new input method, some bug fix

__atx_agent_version__ = '0.3.5'
# 0.3.5 hot fix for session
# 0.3.4 fix session() sometimes can not get mainActivity error
# 0.3.3 /shell support timeout
# 0.3.2 fix dns resolve error when network changes
# 0.3.0 use github.com/codeskyblue/heartbeat library instead of websocket, add /whatsinput
# 0.2.1 support occupy /minicap connection
# 0.2.0 add session support
# 0.1.8 fix screenshot always the same image. (BUG in 0.1.7), add /shell/stream add timeout for /shell
# 0.1.7 fix dns resolve error in /install
# 0.1.6 change download logic. auto fix orientation
# 0.1.5 add singlefight for minicap and minitouch, proxy dial-timeout change 30 to 10
# 0.1.4 phone remote control
# 0.1.2 /download support
# 0.1.1 minicap buildin


# coding: utf-8
#
# Test apk Download from
# https://github.com/appium/java-client/raw/master/src/test/java/io/appium/java_client/ApiDemos-debug.apk

import uiautomator2 as u2
import unittest
import time


class SimpleTestCase(unittest.TestCase):
    @classmethod
    def setUpClass(cls):
        cls.d = u2.connect_usb()
        cls.d.set_orientation('natural')

    def setUp(self):
        self.sess = self.d.session("io.appium.android.apis")
        self.sess.watchers.remove()

    def tearDown(self):
        self.sess.watchers.remove()

    def test_toast_get_message(self):
        d = self.sess
        d.toast.reset()
        assert d.toast.get_message(0) is None
        assert d.toast.get_message(0, default="d") == "d"
        d(text="App").click()
        d(text="Notification").click()
        d(text="NotifyWithText").click()
        d(text="Show Short Notification").click()
        self.assertEqual(d.toast.get_message(2, 5, ""), "Short notification")
        time.sleep(.5)
        self.assertIsNone(d.toast.get_message(0, 0.4))
        # d.toast.reset()
        # d.toast.show("Hello world")
        # self.assertEqual(d.toast.get_message(5, 5), "Hello world")

    def test_scroll(self):
        d = self.sess
        d(text="App").click()
        d(scrollable=True).scroll.to(text="Voice Recognition")

    def test_watchers(self):
        """
        App -> Notification -> Status Bar
        """
        d = self.sess
        d.watchers.remove()
        d.watchers.watched = False

        d.watcher("N").when(text='Notification').click(text='Notification')
        d(text="App").click()
        d.watchers.run()
        self.assertTrue(d(text="Status Bar").wait(timeout=3))
        d.press("back")
        d.press("back")
        # Should auto click Notification when show up
        self.assertFalse(d.watchers.watched)
        d.watchers.watched = True
        self.assertTrue(d.watchers.watched)
        d(text="App").click()
        self.assertTrue(d(text="Status Bar").exists(timeout=3))
        d.watchers.watched = False

    def test_count(self):
        d = self.sess
        count = d(resourceId="android:id/list").child(
            className="android.widget.TextView").count
        self.assertEqual(count, 11)
        self.assertEqual(
            d(resourceId="android:id/list").info['childCount'], 11)
        count = d(resourceId="android:id/list").child(
            className="android.widget.TextView", instance=0).count
        self.assertEqual(count, 1)

    def test_get_text(self):
        d = self.sess
        text = d(resourceId="android:id/list").child(
            className="android.widget.TextView", instance=2).get_text()
        self.assertEqual(text, "App")

    def test_xpath(self):
        d = self.sess
        d.xpath("//*[@text='Media']").click()
        self.assertTrue(d.xpath('//*[contains(@text, "Audio")]').wait(5))


if __name__ == '__main__':
    unittest.main()
